@@ -61,7 +61,7 @@ def free_returned_char_p(result, func, cargs):
     
 
 if os.name == 'nt':
-    lib_name = 'spatialindex1_c.dll'
+    lib_name = 'spatialindex_c.dll'
     try:
         local_dlls = os.path.abspath(os.__file__ + "../../../DLLs")
         original_path = os.environ['PATH']
@@ -88,20 +88,25 @@ else:
 
 rt.Error_GetLastErrorNum.restype = ctypes.c_int
 
+rt.Error_GetLastErrorMsg.argtypes = []
 rt.Error_GetLastErrorMsg.restype = ctypes.POINTER(ctypes.c_char)
 rt.Error_GetLastErrorMsg.errcheck = free_returned_char_p
 
 rt.Error_GetLastErrorMethod.restype = ctypes.POINTER(ctypes.c_char)
 rt.Error_GetLastErrorMethod.errcheck = free_returned_char_p
 
+rt.Error_GetErrorCount.argtypes = []
 rt.Error_GetErrorCount.restype=ctypes.c_int
 
+rt.Error_Reset.argtypes = []
+rt.Error_Reset.restype = None
+
 rt.Index_Create.argtypes = [ctypes.c_void_p]
 rt.Index_Create.restype = ctypes.c_void_p
 rt.Index_Create.errcheck = check_void
 
 NEXTFUNC = ctypes.CFUNCTYPE(ctypes.c_int, 
-                            ctypes.POINTER(ctypes.c_uint64),
+                            ctypes.POINTER(ctypes.c_int64),
                             ctypes.POINTER(ctypes.POINTER(ctypes.c_double)),
                             ctypes.POINTER(ctypes.POINTER(ctypes.c_double)),
                             ctypes.POINTER(ctypes.c_uint32),
@@ -121,7 +126,7 @@ rt.Index_GetProperties.restype = ctypes.c_void_p
 rt.Index_GetProperties.errcheck = check_void
 
 rt.Index_DeleteData.argtypes = [ctypes.c_void_p, 
-                                ctypes.c_uint64, 
+                                ctypes.c_int64, 
                                 ctypes.POINTER(ctypes.c_double), 
                                 ctypes.POINTER(ctypes.c_double), 
                                 ctypes.c_uint32]
@@ -129,7 +134,7 @@ rt.Index_DeleteData.restype = ctypes.c_int
 rt.Index_DeleteData.errcheck = check_return
 
 rt.Index_InsertData.argtypes = [ctypes.c_void_p, 
-                                ctypes.c_uint64, 
+                                ctypes.c_int64, 
                                 ctypes.POINTER(ctypes.c_double), 
                                 ctypes.POINTER(ctypes.c_double), 
                                 ctypes.c_uint32, 
@@ -162,7 +167,7 @@ rt.Index_Intersects_id.argtypes = [ctypes.c_void_p,
                                     ctypes.POINTER(ctypes.c_double), 
                                     ctypes.POINTER(ctypes.c_double), 
                                     ctypes.c_uint32, 
-                                    ctypes.POINTER(ctypes.POINTER(ctypes.c_uint64)),
+                                    ctypes.POINTER(ctypes.POINTER(ctypes.c_int64)),
                                     ctypes.POINTER(ctypes.c_uint64)]
 rt.Index_Intersects_id.restype = ctypes.c_int
 rt.Index_Intersects_id.errcheck = check_return
@@ -186,7 +191,7 @@ rt.Index_NearestNeighbors_id.argtypes = [  ctypes.c_void_p,
                                             ctypes.POINTER(ctypes.c_double), 
                                             ctypes.POINTER(ctypes.c_double), 
                                             ctypes.c_uint32, 
-                                            ctypes.POINTER(ctypes.POINTER(ctypes.c_uint64)),
+                                            ctypes.POINTER(ctypes.POINTER(ctypes.c_int64)),
                                             ctypes.POINTER(ctypes.c_uint64)]
 rt.Index_NearestNeighbors_id.restype = ctypes.c_int
 rt.Index_NearestNeighbors_id.errcheck = check_return
@@ -206,6 +211,10 @@ rt.Index_DestroyObjResults.argtypes = [ctypes.POINTER(ctypes.POINTER(ctypes.c_vo
 rt.Index_DestroyObjResults.restype = None
 rt.Index_DestroyObjResults.errcheck = check_void_done
 
+rt.Index_ClearBuffer.argtypes = [ctypes.c_void_p]
+rt.Index_ClearBuffer.restype = None
+rt.Index_ClearBuffer.errcheck = check_void_done
+
 rt.Index_Free.argtypes = [ctypes.POINTER(ctypes.c_void_p)]
 rt.Index_Free.restype = None
 rt.Index_Free.errcheck = check_void_done
@@ -228,9 +237,10 @@ rt.IndexItem_GetBounds.restype = ctypes.c_int
 rt.IndexItem_GetBounds.errcheck = check_value
 
 rt.IndexItem_GetID.argtypes = [ctypes.c_void_p]
-rt.IndexItem_GetID.restype = ctypes.c_uint64
+rt.IndexItem_GetID.restype = ctypes.c_int64
 rt.IndexItem_GetID.errcheck = check_value
 
+rt.IndexProperty_Create.argtypes = []
 rt.IndexProperty_Create.restype = ctypes.c_void_p
 rt.IndexProperty_Create.errcheck = check_void
 
@@ -422,6 +432,22 @@ rt.IndexProperty_GetFileNameExtensionIdx.argtypes = [ctypes.c_void_p]
 rt.IndexProperty_GetFileNameExtensionIdx.errcheck = free_returned_char_p
 rt.IndexProperty_GetFileNameExtensionIdx.restype = ctypes.POINTER(ctypes.c_char)
 
+rt.IndexProperty_SetCustomStorageCallbacksSize.argtypes = [ctypes.c_void_p, ctypes.c_uint32]
+rt.IndexProperty_SetCustomStorageCallbacksSize.restype = ctypes.c_int
+rt.IndexProperty_SetCustomStorageCallbacksSize.errcheck = check_return
+
+rt.IndexProperty_GetCustomStorageCallbacksSize.argtypes = [ctypes.c_void_p]
+rt.IndexProperty_GetCustomStorageCallbacksSize.restype = ctypes.c_uint32
+rt.IndexProperty_GetCustomStorageCallbacksSize.errcheck = check_value
+
+rt.IndexProperty_SetCustomStorageCallbacks.argtypes = [ctypes.c_void_p, ctypes.c_void_p]
+rt.IndexProperty_SetCustomStorageCallbacks.restype = ctypes.c_int
+rt.IndexProperty_SetCustomStorageCallbacks.errcheck = check_return
+
+rt.IndexProperty_GetCustomStorageCallbacks.argtypes = [ctypes.c_void_p]
+rt.IndexProperty_GetCustomStorageCallbacks.restype = ctypes.c_void_p
+rt.IndexProperty_GetCustomStorageCallbacks.errcheck = check_value
+
 rt.IndexProperty_SetIndexID.argtypes = [ctypes.c_void_p, ctypes.c_int64]
 rt.IndexProperty_SetIndexID.restype = ctypes.c_int
 rt.IndexProperty_SetIndexID.errcheck = check_return
@@ -430,5 +456,13 @@ rt.IndexProperty_GetIndexID.argtypes = [ctypes.c_void_p]
 rt.IndexProperty_GetIndexID.restype = ctypes.c_int64
 rt.IndexProperty_GetIndexID.errcheck = check_value
 
+rt.SIDX_NewBuffer.argtypes = [ctypes.c_uint]
+rt.SIDX_NewBuffer.restype = ctypes.c_void_p
+rt.SIDX_NewBuffer.errcheck = check_void
+
+rt.SIDX_DeleteBuffer.argtypes = [ctypes.c_void_p]
+rt.SIDX_DeleteBuffer.restype = None
+
+rt.SIDX_Version.argtypes = []
 rt.SIDX_Version.restype = ctypes.POINTER(ctypes.c_char)
 rt.SIDX_Version.errcheck = free_returned_char_p
